---
name: 💡 Feature Request
about: Submit a feature request to help us improve
labels: Feature Request
---

<!-- Please search existing issues to avoid creating duplicates. -->

### Description

Describe the feature (e.g., new functions/tutorials) you would like to propose.
Tell us what can be achieved with this new feature and what's the expected outcome.

### Source code

```
Paste your source code here if have sample code to share.
```
